# $Id: browse.tcl 722 2006-09-18 21:01:30Z sergei $

proc iq_browse {connid from lang child} {
    browser::parse_items $from $child

    return {}
}

iq::register_handler set {} jabber:iq:browse \
    [namespace current]::iq_browse

proc iq_browse_reply {connid from lang child} {
    set restags {}
    foreach ns $::iq::supported_ns {
	lappend restags [jlib::wrapper:createtag ns \
			     -chdata $ns]
    }
    
    set res [jlib::wrapper:createtag query \
		 -vars {xmlns    jabber:iq:browse \
			category user \
			type     client \
			name     Tkabber} \
		 -subtags $restags]
    
    return [list result $res]
}

iq::register_handler get {} jabber:iq:browse \
    [namespace current]::iq_browse_reply

